@@ -1,4 +1,4 @@
-// Copyright © 2023-2024 Advanced Micro Devices, Inc.
+// Copyright © 2023-2025 Advanced Micro Devices, Inc.
 // SPDX-License-Identifier: MIT
 
 #ifndef AOTRITON_V2_INTERNAL_UTIL_H
@@ -12,11 +12,22 @@
 
 namespace AOTRITON_NS {
 
-inline uint32_t bit_width(uint32_t x) {
-  if (x == 0)
-    return 0;
-  return (int)(CHAR_BIT * sizeof(x)) - __builtin_clz(x);
-}
+#if defined(_MSC_VER) && !defined(__clang__)
+#include <intrin.h>
+    static inline uint32_t bit_width(uint32_t x) {
+      if (x == 0)
+        return 0;
+      unsigned long index;
+      _BitScanReverse(&index, x);
+      return index + 1;
+    }
+#else
+    static inline uint32_t bit_width(uint32_t x) {
+      if (x == 0)
+        return 0;
+      return (int)(CHAR_BIT * sizeof(x)) - __builtin_clz(x);
+    }
+#endif
 
 inline uint32_t bit_ceil(uint32_t x) {
   return 1 << bit_width(x - 1);
