@@ -1,4 +1,4 @@
-// Copyright © 2023-2024 Advanced Micro Devices, Inc.
+// Copyright © 2023-2025 Advanced Micro Devices, Inc.
 // SPDX-License-Identifier: MIT
 
 #ifndef AOTRITON_V2_API_RUNTIME_H
@@ -12,7 +12,7 @@ namespace AOTRITON_NS {
 // This is not a class for stream management (at least for now), but a way to
 // make sure AOTriton APIs can have python bindings with pybind11
 template<typename DeviceStreamType>
-class StreamTemplate {
+class AOTRITON_API StreamTemplate {
 public:
   StreamTemplate()
     : stream_(nullptr) {
